import { PartialFavorite, GDPRFavorites } from "../types/GDPRExtended";
export interface FavoriteIndex {
    [tweetId: string]: PartialFavorite;
}
export interface FavoriteDateIndex {
    [year: string]: {
        [month: string]: FavoriteIndex;
    };
}
export declare class FavoriteArchive {
    protected _all: PartialFavorite[];
    protected _index: FavoriteIndex;
    protected _date_index: FavoriteDateIndex;
    protected fav_set: Set<string>;
    add(favs: GDPRFavorites | PartialFavorite[]): void;
    /**
     * Check if {tweet_id} has been favorited.
     */
    has(tweet_id: string): boolean;
    /**
     * Get favorites informations of {tweet_id}.
     *
     * If {tweet_id} is not favorited, returns `undefined`.
     */
    get(tweet_id: string): PartialFavorite;
    [Symbol.iterator](): Generator<PartialFavorite, void, undefined>;
    /**
     * Get all the registred favorites
     */
    get all(): PartialFavorite[];
    /**
     * Favorites sorted by year then months.
     *
     * Favs on `2010-10` are favorites than cannot be date classed.
     */
    get index(): FavoriteDateIndex;
    /**
     * Get all favorited tweets in the archive, inside a Set for quick check (like old `archive.extended_gdpr.favorites`).
     */
    get registred(): Set<string>;
    /**
     * Number of favorites.
     */
    get length(): number;
    /** `true` if this archive's favorites supported "extended" properties: `.fullText` and `.expandedUrl`. */
    get has_extended_favorites(): boolean;
}
