"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Settings_1 = __importDefault(require("../utils/Settings"));
const exported_helpers_1 = require("../utils/exported_helpers");
class FavoriteArchive {
    constructor() {
        this._index = {};
    }
    add(favs) {
        for (const f of favs) {
            if ('like' in f) {
                this._index[f.like.tweetId] = f.like;
            }
            else {
                this._index[f.tweetId] = f;
            }
        }
        this._all = undefined;
        this._date_index = undefined;
        this.fav_set = undefined;
    }
    /**
     * Check if {tweet_id} has been favorited.
     */
    has(tweet_id) {
        return tweet_id in this._index;
    }
    /**
     * Get favorites informations of {tweet_id}.
     *
     * If {tweet_id} is not favorited, returns `undefined`.
     */
    get(tweet_id) {
        return this._index[tweet_id];
    }
    *[Symbol.iterator]() {
        yield* this.all;
    }
    /**
     * Get all the registred favorites
     */
    get all() {
        if (this._all)
            return this._all;
        if (Settings_1.default.ENABLE_CACHE) {
            return this._all = exported_helpers_1.sortFavorites(Object.values(this._index), "asc");
        }
        return exported_helpers_1.sortFavorites(Object.values(this._index), "asc");
    }
    /**
     * Favorites sorted by year then months.
     *
     * Favs on `2010-10` are favorites than cannot be date classed.
     */
    get index() {
        if (this._date_index)
            return this._date_index;
        const index = {};
        for (const fav of this.all) {
            const d = exported_helpers_1.dateFromFavorite(fav);
            const year = d.getFullYear(), month = d.getMonth() + 1;
            if (!(year in index)) {
                index[year] = {};
            }
            if (!(month in index[year])) {
                index[year][month] = {};
            }
            index[year][month][fav.tweetId] = fav;
        }
        if (Settings_1.default.ENABLE_CACHE) {
            return this._date_index = index;
        }
        return index;
    }
    /**
     * Get all favorited tweets in the archive, inside a Set for quick check (like old `archive.extended_gdpr.favorites`).
     */
    get registred() {
        if (this.fav_set) {
            return this.fav_set;
        }
        return this.fav_set = new Set(Object.keys(this._index));
    }
    /**
     * Number of favorites.
     */
    get length() {
        return this.all.length;
    }
    /** `true` if this archive's favorites supported "extended" properties: `.fullText` and `.expandedUrl`. */
    get has_extended_favorites() {
        if (this.length) {
            return 'fullText' in this.all[0];
        }
        return false;
    }
}
exports.FavoriteArchive = FavoriteArchive;
